# Table of Contents

- [it-components-in-reference-catalog](<./it-components-in-reference-catalog.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [IT Components in the Reference Catalog](<./IT-Components-in-the-Reference-Catalog.md>)
  - [Overview](<./IT-Components-in-the-Reference-Catalog/Overview.md>)
  - [Benefits](<./IT-Components-in-the-Reference-Catalog/Benefits.md>)
  - [IT Components in Scope](<./IT-Components-in-the-Reference-Catalog/IT-Components-in-Scope.md>)
  - [IT Components Out of Scope](<./IT-Components-in-the-Reference-Catalog/IT-Components-Out-of-Scope.md>)
  - [Fact Sheet Attributes](<./IT-Components-in-the-Reference-Catalog/Fact-Sheet-Attributes.md>)
  - [Vendor Lifecycle Dates](<./IT-Components-in-the-Reference-Catalog/Vendor-Lifecycle-Dates.md>)
  - [Configuring Settings for Syncing Fields and Establishing Relations](<./IT-Components-in-the-Reference-Catalog/Configuring-Settings-for-Syncing-Fields-and-Establishing-Relations.md>)
  - [Resyncing IT Components](<./IT-Components-in-the-Reference-Catalog/Resyncing-IT-Components.md>)
  - [Linking IT Components to Catalog Items](<./IT-Components-in-the-Reference-Catalog/Linking-IT-Components-to-Catalog-Items.md>)
  - [Bulk Linking IT Component Fact Sheets](<./IT-Components-in-the-Reference-Catalog/Bulk-Linking-IT-Component-Fact-Sheets.md>)
  - [Ignoring IT Component Fact Sheets](<./IT-Components-in-the-Reference-Catalog/Ignoring-IT-Component-Fact-Sheets.md>)
  - [Changing the Link to a Different Item](<./IT-Components-in-the-Reference-Catalog/Changing-the-Link-to-a-Different-Item.md>)
  - [Report Missing Data in Catalog Items](<./IT-Components-in-the-Reference-Catalog/Report-Missing-Data-in-Catalog-Items.md>)
  - [Linking an IT Component Fact Sheet from the Fact Sheet Page](<./IT-Components-in-the-Reference-Catalog/Linking-an-IT-Component-Fact-Sheet-from-the-Fact-Sheet-Page.md>)
  - [Linking an IT Component Fact Sheet During Fact Sheet Creation](<./IT-Components-in-the-Reference-Catalog/Linking-an-IT-Component-Fact-Sheet-During-Fact-Sheet-Creation.md>)
  - [Linking Multiple IT Components to the Same Catalog Item](<./IT-Components-in-the-Reference-Catalog/Linking-Multiple-IT-Components-to-the-Same-Catalog-Item.md>)
  - [Implications of Meta Model v4 on IT Components in the Catalog](<./IT-Components-in-the-Reference-Catalog/Implications-of-Meta-Model-v4-on-IT-Components-in-the-Catalog.md>)
  - [Was this page helpful?](<./IT-Components-in-the-Reference-Catalog/Was-this-page-helpful.md>)
